<?php

namespace Erp\Master\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Erp\Master\Http\Requests\StudentActionsRequest;
use Erp\Master\Actions\StudentActions;

/**
 * Admin web controller class.
 */
class StudentActionsController extends BaseController
{

    /**
     * Action controller function for student.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(StudentActionsRequest $request, $action)
    {
        try {
            $student = StudentActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('master::student.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('master/student/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('master/student/' . $action))
                ->redirect();
        }
    }
}
