<?php

namespace Erp\Master\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Erp\Master\Actions\StudentReport;
use Erp\Master\Http\Requests\StudentReportRequest;

/**
 * Admin web controller class.
 */
class StudentReportController extends BaseController
{
    /**
     * Action controller function for student.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(StudentReportRequest $request, $report)
    {
        try {
        
            $this->model = app(Student::class);
            $data = StudentReport::run($request, $report);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('master::student.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('master/student/' . $report))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('master/student/' . $report))
                ->redirect();
        }
    }
}
