<?php

namespace Erp\Master\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Erp\Master\Events\StudentWorkflow as StudentWorkflowEvent;
use Erp\Master\Notifications\StudentWorkflow as StudentWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class StudentWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(StudentWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $student is submitted.
     *
     * @param StudentWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(StudentWorkflowEvent $event)
    {
        $client = $event->student->client;
        Notification::send($client, new StudentWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $student is published.
     *
     * @param StudentWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(StudentWorkflowEvent $event)
    {
        $client = $event->student->client;
        Notification::send($client, new StudentWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $student is approved.
     *
     * @param StudentWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(StudentWorkflowEvent $event)
    {
        $client = $event->student->client;
        Notification::send($client, new StudentWorkflowNotification($event));
    }

    /**
     * Handles the $student workflow event as a listener.
     *
     * @param StudentWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(StudentWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
