<?php
namespace Erp\Master\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Erp\Master\Events\StudentAction as StudentActionEvent;
use Erp\Master\Models\Student;

class StudentAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $student;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param StudentActionEvent $student
     */
    public function __construct(StudentActionEvent $student)
    {
        $this->action = $event->action;
        $this->student = $student;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Student Approved - ' . config('app.name'))
            ->view('master::student.email.action', ['data' => $this->student]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
